import 'package:flutter/material.dart';
import '../services/services.dart';

import '../models/models.dart';

class CategoriaProductoViewModel extends ChangeNotifier {
  List<CategoriaProducto> _categoriaProductos = [];
  CategoriaProducto? _selectedCategoriaProducto;
  bool _isLoading = true;

  String _busqueda = "";
  String get busqueda => _busqueda;

  List<CategoriaProducto> get categoriaProductos => _categoriaProductos;
  CategoriaProducto? get selectedCategoriaProducto =>
      _selectedCategoriaProducto;

  bool get isLoading => _isLoading;

  Future<List<CategoriaProducto>> getCategoriaProducto(
      {String? q, bool segmentar = false}) async {
    _categoriaProductos =
        await CategoriaProductoService().fetchList(q: q, segmentar: segmentar);
    return _categoriaProductos;
  }

  //Metodo para obtener lista de CategoriaProducto
  Future<void> fetchCategoriaProductos({bool segmentar = false}) async {
    _categoriaProductos =
        await CategoriaProductoService().fetchList(segmentar: segmentar);
    notifyListeners();
  }

  int pagina = 1;
  int totalPaginas = 1;
  int limite = 10;

  void setLoading(bool loading) {
    _isLoading = loading;
    notifyListeners();
  }

  setBusqueda(String value) {
    _busqueda = value;
    notifyListeners();
  }

  CategoriaProducto selectCategoriaProducto(
      CategoriaProducto categoriaProducto) {
    _selectedCategoriaProducto = categoriaProducto;
    return categoriaProducto;
  }

  cambiarPagina(int nuevaPagina, {bool segmentar = false}) {
    pagina = nuevaPagina;
    fetchCategoriaProductos();
  }

  Future<void> addCategoriaProducto({
    required String nombre,
  }) async {
    await CategoriaProductoService().postCategoriaProducto(
      nombre: nombre,
    );
    await fetchCategoriaProductos();
    notifyListeners();
  }

  Future<void> editCategoriaProducto({
    required int id,
    required String nombre,
  }) async {
    await CategoriaProductoService().editCategoriaProducto(
      id: id,
      nombre: nombre,
    );
    await fetchCategoriaProductos();
    notifyListeners();
  }

  setIsLoading(bool loading) {
    _isLoading = loading;
    notifyListeners();
  }

  Future<void> deleteCategoriaProducto(int id) async {
    await CategoriaProductoService().deleteCategoriaProducto(id: id);
    await fetchCategoriaProductos();
    notifyListeners();
  }
}
