import 'package:flutter/material.dart';

import '../data/api_response.dart';
import '../services/base_service.dart';
import '../models/models.dart';

class ProductoViewModel<T> extends ChangeNotifier {
  String _busqueda = "";
  String get busqueda => _busqueda;

  List<Producto> _registros = [];
  Producto? _selectedModelo;
  bool _isLoading = false;

  List<Producto> get registros => _registros;
  Producto? get selectedProducto => _selectedModelo;
  bool get isLoading => _isLoading;

  int pagina = 1;
  int totalPaginas = 1;
  int limite = 10;

  setBusqueda(String value) {
    _busqueda = value;
    notifyListeners();
  }

  Future<List<Producto>> fetchRegistros(
      {CategoriaProducto? categoriaProducto,
      String? q,
      bool segmentar = false}) async {
    Map<String, String> parametros = {
      "ordenar": "nombre-asc",
      "pagina": "$pagina",
      "limite": "$limite",
      "expand": "categoria"
    };
    if (_busqueda.isNotEmpty) {
      parametros["q"] = _busqueda;
    }
    if (categoriaProducto != null) {
      parametros['idCategoria'] = categoriaProducto.id.toString();
    }
    if (segmentar) {
      parametros['segmentar'] = "1";
    }
    var r = ApiResponse(
        await BaseService().get("admin/producto", queryParameters: parametros));
    pagina = r.paginacion!.pagina;
    var total = r.paginacion!.total / r.paginacion!.limite;
    totalPaginas = total > 0 ? total.ceil() : 1;
    List<Producto> aux = [];
    if (r.isOk) {
      for (var x in r.resultados!) {
        Producto modelo = Producto.fromJson(x);
        aux.add(modelo);
      }
    }
    _registros = aux;
    notifyListeners();
    return _registros;
  }

  selectModelo(Producto Producto) {
    _selectedModelo = Producto;
    notifyListeners();
  }

  setIsLoading(bool loading) {
    _isLoading = loading;
    notifyListeners();
  }

  cambiarPagina(int nuevaPagina,
      {CategoriaProducto? categoriaProducto, bool segmentar = false}) {
    pagina = nuevaPagina;
    fetchRegistros(categoriaProducto: categoriaProducto, segmentar: segmentar);
  }

  Future<void> guardarModelo({
    required Producto modelo,
    required String nombre,
    required String descripcion,
    String? descuento,
    required int existencia,
    required int idCategoria,
    required String precio,
    String? venceDescuento,
  }) async {
    modelo.nombre = nombre;
    modelo.descripcion = descripcion;
    modelo.idCategoria = idCategoria;
    modelo.descuento = descuento;
    modelo.existencia = existencia;
    modelo.precio = precio;
    modelo.venceDescuento = venceDescuento;
    var r = await BaseService()
        .post("admin/producto/guardar", body: modelo.toJson());
    if (r.statusCode == 200) {}
    notifyListeners();
  }
}
