// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:yoshi_papas_app/widgets/widgets.dart';
import 'package:provider/provider.dart';

import '../../models/models.dart';
import '../../viewmodels/viewmodels.dart';

class ProductoForm extends StatefulWidget {
  const ProductoForm({Key? key}) : super(key: key);

  @override
  State<ProductoForm> createState() => Formulario();
}

class Formulario extends State<ProductoForm> {
  final _nombre = TextEditingController();
  final _descripcion = TextEditingController();
  final _precio = TextEditingController();
  final _existencia = TextEditingController();
  final _descuento = TextEditingController();
  final _busquedaCategoria = TextEditingController();
  final _venceDescuento = TextEditingController();
  CategoriaProducto? categoriaProducto;

  @override
  void initState() {
    super.initState();
    Future(() async {
      Provider.of<ProductoViewModel>(context, listen: false).setIsLoading(true);
      final mvm = Provider.of<ProductoViewModel>(context, listen: false);
      await Provider.of<CategoriaProductoViewModel>(context, listen: false)
          .fetchCategoriaProductos();
      List<CategoriaProducto> catProductos =
          Provider.of<CategoriaProductoViewModel>(context, listen: false)
              .categoriaProductos;
      Producto? modelo = mvm.selectedProducto;
      if (modelo != null && modelo.id > 0) {
        setState(() {
          _nombre.text = modelo.nombre.toString();
          _descripcion.text = modelo.descripcion.toString();
          _precio.text = modelo.precio.toString();
          _existencia.text = modelo.existencia.toString();
          _descuento.text = modelo.descuento.toString();
          if (modelo.idCategoria != null &&
              modelo.idCategoria! != "" &&
              modelo.categoria != null) {
            categoriaProducto = modelo.categoria;
          }
          if (categoriaProducto == null && catProductos.isNotEmpty) {
            categoriaProducto = catProductos.first;
          }
        });
      }
      Provider.of<ProductoViewModel>(context, listen: false)
          .setIsLoading(false);
    });
  }

  @override
  void dispose() {
    super.dispose();
    _descripcion.dispose();
    _nombre.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final mvm = Provider.of<ProductoViewModel>(context);
    final evm = Provider.of<CategoriaProductoViewModel>(context);
    if (mvm.isLoading) return const Cargando();
    final producto = mvm.selectedProducto;
    List<CategoriaProducto> categoriaProductos = [];
    if (evm.categoriaProductos.isNotEmpty) {
      categoriaProductos = evm.categoriaProductos;
    }

    return Scaffold(
      appBar: encabezado(titulo: "Producto"),
      body: SingleChildScrollView(
        padding: const EdgeInsets.all(8),
        child: Column(
          children: [
            tarjeta(
              Padding(
                padding: const EdgeInsets.all(8),
                child: Column(
                  children: [
                    categoriaProductos.isNotEmpty
                        ? AppDropdownSearch(
                            etiqueta: 'Categoría',
                            controller: _busquedaCategoria,
                            selectedItem: categoriaProducto,
                            onPressedClear: () {
                              categoriaProducto = null;
                            },
                            itemAsString: (item) => '${item.nombre}',
                            asyncItems: (text) async {
                              final xregistros = await evm.getCategoriaProducto(
                                  q: text, segmentar: true);
                              return xregistros;
                            },
                            onChanged: (value) {
                              categoriaProducto = value;
                            },
                            validator: (value) {
                              if (value == null) {
                                return 'Seleccione';
                              }
                              return null;
                            },
                          )
                        : Container(),
                    Row(
                      children: [
                        Expanded(
                          child: AppTextField(
                            maxLength: 100,
                            etiqueta: 'Nombre',
                            controller: _nombre,
                            hintText: 'Nombre producto',
                          ),
                        ),
                      ],
                    ),
                    Row(
                      children: [
                        Expanded(
                          child: AppTextField(
                            maxLength: 100,
                            etiqueta: 'Precio',
                            controller: _precio,
                            hintText: 'Precio del producto',
                          ),
                        ),
                      ],
                    ),
                    Row(
                      children: [
                        Expanded(
                          child: AppTextField(
                            maxLength: 100,
                            etiqueta: 'Existencia',
                            controller: _existencia,
                            hintText: 'Existencia del producto',
                          ),
                        ),
                      ],
                    ),
                    Row(
                      children: [
                        Expanded(
                          child: AppTextField(
                            maxLength: 1000,
                            maxLines: 3,
                            etiqueta: 'Descripción',
                            controller: _descripcion,
                            hintText: 'descripción del producto',
                          ),
                        ),
                      ],
                    ),
                  ],
                ),
              ),
            ),
            const SizedBox(height: 15),
            boton("Guardar", () async {
              if (categoriaProducto == null ||
                  categoriaProducto!.id == null ||
                  categoriaProducto!.id == "") {
                await alerta(context, etiqueta: "Seleccionar categoría");
                return;
              }
              Provider.of<ProductoViewModel>(context, listen: false)
                  .setIsLoading(true);
              await mvm.guardarModelo(
                  modelo: producto!,
                  nombre: _nombre.text,
                  descripcion: _descripcion.text,
                  precio: _precio.text,
                  descuento: _descuento.text,
                  existencia: int.tryParse(_existencia.text) ?? 0,
                  venceDescuento: _venceDescuento.text,
                  idCategoria: categoriaProducto?.id ?? 0);
              Provider.of<ProductoViewModel>(context, listen: false)
                  .setIsLoading(false);
              if (context.mounted) {
                Navigator.pop(context);
              }
            }),
          ],
        ),
      ),
    );
  }
}
